<?php

declare(strict_types=1);

final class FingerprintPutController extends AbstractController
{
	protected string $route = '/api/v1/fingerprint/{fingerprintId}';
	protected array $mandatoryAttributes = [
		'fingerprint',
	];

	private int $fingerprintId;

	public function __construct(string $url)
	{
		parent::__construct($url);

		$this->fingerprintId = (int)$this->getUrlParamInt('fingerprintId');
	}

	public function handle(): void
	{
		if (!$this->isUserLoggedIn()) {
			return;
		}

		parent::handle();

		$this->response = new ApiJsonResponse();

		try {
			$fingerprint = new Fingerprint($this->fingerprintId);

			if ($this->hasUserPermission($fingerprint->getUserId()) || $this->handleFingerprint($fingerprint)) {
				return;
			}

			$this->response->setMessage('Fingerprint did not differ from the stored. Nothing changed.');
		} catch (Throwable $e) {
			$this->response->setStatus(ServerStatus::BAD_REQUEST);
			$this->response->setParameter('success', false);
			$this->response->setMessage($e->getMessage());
		}
	}

	public function handleFingerprint(Fingerprint $fingerprint): bool
	{
		if ($fingerprint->getFingerprint() !== $this->jsonBody->fingerprint) {
			$fingerprint->setFingerprint($this->jsonBody->fingerprint);
			$fingerprint->Save();

			return true;
		}

		return false;
	}
}